PrinterConnectionStatus enum

PrinterConnectionStatus Represents the different connection statuses of a printer.

Inheritance
Available extensions

Values

initial → const PrinterConnectionStatus

Initial connection status.

loading → const PrinterConnectionStatus

Loading connection status.

connected → const PrinterConnectionStatus

Connected connection status.

disconnected → const PrinterConnectionStatus

Disconnected connection status.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isConnected bool

Available on PrinterConnectionStatus, provided by the PrinterStatusX extension

Checks if the connection status is PrinterConnectionStatus.connected.
no setter
isDisconnected bool

Available on PrinterConnectionStatus, provided by the PrinterStatusX extension

Checks if the connection status is PrinterConnectionStatus.disconnected.
no setter
isInitial bool

Available on PrinterConnectionStatus, provided by the PrinterStatusX extension

Checks if the connection status is PrinterConnectionStatus.initial.
no setter
isLoading bool

Available on PrinterConnectionStatus, provided by the PrinterStatusX extension

Checks if the connection status is PrinterConnectionStatus.loading.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PrinterConnectionStatus>
A constant List of the values in this enum, in order of their declaration.