StringX extension

Extension on the String class providing conversion functions for converting strings to printer connection and operation statuses.

on

Methods

toPrinterProcessStatus() PrinterOperationStatus

Available on String, provided by the StringX extension

Converts a string to the corresponding PrinterOperationStatus value.
toPrinterStatus() PrinterConnectionStatus

Available on String, provided by the StringX extension

Converts a string to the corresponding PrinterConnectionStatus value.