PrinterOperationStatus enum
PrinterOperationStatus Represents the different operation statuses of a printer.
- Inheritance
- Available extensions
Values
- transmitting → const PrinterOperationStatus
-
Transmitting operation status.
- idle → const PrinterOperationStatus
-
Idle operation status.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isIdle → bool
-
Available on PrinterOperationStatus, provided by the PrinterProcessStatusX extension
Checks if the operation status is PrinterOperationStatus.idle.no setter - isTransmitting → bool
-
Available on PrinterOperationStatus, provided by the PrinterProcessStatusX extension
Checks if the operation status is PrinterOperationStatus.transmitting.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PrinterOperationStatus> - A constant List of the values in this enum, in order of their declaration.